@@ -90,7 +90,6 @@ CREATE TABLE IF NOT EXISTS `inlong_cluster_tag`
     `cluster_tag` varchar(128) NOT NULL COMMENT 'Cluster tag',
     `ext_params`  mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
     `description` varchar(256)          DEFAULT '' COMMENT 'Description of cluster tag',
-    `tenant`      varchar(256)          DEFAULT 'public' COMMENT 'Inlong tenant of the inlong cluster tag',
     `in_charges`  varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
     `status`      int(4)                DEFAULT '0' COMMENT 'Cluster status',
     `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
@@ -120,7 +119,6 @@ CREATE TABLE IF NOT EXISTS `inlong_cluster`
     `ext_params`            mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
     `description`           varchar(256)          DEFAULT '' COMMENT 'Description of cluster',
     `heartbeat`             mediumtext            DEFAULT NULL COMMENT 'Cluster heartbeat info',
-    `tenant`                varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of cluster',
     `in_charges`            varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
     `status`                int(4)                DEFAULT '0' COMMENT 'Cluster status',
     `is_deleted`            int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
@@ -131,8 +129,7 @@ CREATE TABLE IF NOT EXISTS `inlong_cluster`
     `version`               int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
     PRIMARY KEY (`id`),
     UNIQUE KEY `unique_inlong_cluster` (`name`, `type`, `is_deleted`),
-    INDEX `cluster_type_index` (`type`),
-    INDEX `cluster_tenant_index` (`tenant`, `is_deleted`)
+    INDEX `cluster_type_index` (`type`)
 ) ENGINE = InnoDB
   DEFAULT CHARSET = utf8mb4 COMMENT ='Inlong cluster table';
 
@@ -250,6 +247,7 @@ CREATE TABLE IF NOT EXISTS `inlong_stream`
     `description`      varchar(256)          DEFAULT '' COMMENT 'Description of inlong stream',
     `mq_resource`      varchar(128)          DEFAULT NULL COMMENT 'MQ resource, in one stream, corresponding to the filter ID of TubeMQ, corresponding to the topic of Pulsar',
     `data_type`        varchar(20)           DEFAULT NULL COMMENT 'Data type, including: CSV, KEY-VALUE, JSON, AVRO, etc.',
+    `wrap_type`        varchar(256)          DEFAULT 'INLONG_MSG_V0' COMMENT 'The message body wrap type, including: RAW, INLONG_MSG_V0, INLONG_MSG_V1, etc',
     `data_encoding`    varchar(8)            DEFAULT 'UTF-8' COMMENT 'Data encoding format, including: UTF-8, GBK, etc.',
     `data_separator`   varchar(8)            DEFAULT NULL COMMENT 'The source data field separator',
     `data_escape_char` varchar(8)            DEFAULT NULL COMMENT 'Source data field escape character, the default is NULL (NULL), stored as 1 character',
@@ -321,6 +319,9 @@ CREATE TABLE IF NOT EXISTS `operation_log`
 (
     `id`                  int(11)   NOT NULL AUTO_INCREMENT,
     `authentication_type` varchar(64)        DEFAULT NULL COMMENT 'Authentication type',
+    `inlong_group_id`     varchar(256)       DEFAULT NULL COMMENT 'Inlong group id',
+    `inlong_stream_id`    varchar(256)       DEFAULT NULL COMMENT 'Inlong stream id',
+    `operation_target`    varchar(256)       DEFAULT NULL COMMENT 'Operation target',
     `operation_type`      varchar(256)       DEFAULT NULL COMMENT 'Operation type',
     `http_method`         varchar(64)        DEFAULT NULL COMMENT 'Request method',
     `invoke_method`       varchar(256)       DEFAULT NULL COMMENT 'Invoke method',
@@ -334,8 +335,10 @@ CREATE TABLE IF NOT EXISTS `operation_log`
     `status`              int(4)             DEFAULT NULL COMMENT 'Operate status',
     `request_time`        timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Request time',
     `err_msg`             mediumtext COMMENT 'Error message',
-    PRIMARY KEY (`id`)
-) ENGINE = InnoDB
+    PRIMARY KEY (`id`),
+    INDEX `operation_log_group_stream_index` (`inlong_group_id`, `inlong_stream_id`),
+    INDEX `operation_log_request_time_index` (`request_time`)
+    ) ENGINE = InnoDB
   DEFAULT CHARSET = utf8mb4;
 
 -- ----------------------------
@@ -866,16 +869,29 @@ CREATE TABLE IF NOT EXISTS `audit_base`
 INSERT INTO `audit_base`(`name`, `type`, `is_sent`, `audit_id`)
 VALUES ('audit_sdk_collect', 'SDK', 0, '1'),
        ('audit_sdk_sent', 'SDK', 1, '2'),
-       ('audit_agent_collect', 'AGENT', 0, '3'),
+       ('audit_agent_read', 'AGENT', 0, '3'),
        ('audit_agent_sent', 'AGENT', 1, '4'),
+       ('audit_agent_sent_failed', 'AGENT', 2, '10004'),
+       ('audit_agent_read_realtime', 'AGENT', 3, '30001'),
+       ('audit_agent_send_realtime', 'AGENT', 4, '30002'),
+       ('audit_agent_add_instance_mem', 'AGENT', 5, '30003'),
+       ('audit_agent_del_instance_mem', 'AGENT', 6, '30004'),
+       ('audit_agent_add_instance_db', 'AGENT', 7, '30005'),
+       ('audit_agent_del_instance_db', 'AGENT', 8, '30006'),
+       ('audit_agent_task_mgr_heartbeat', 'AGENT', 9, '30007'),
+       ('audit_agent_task_heartbeat', 'AGENT', 10, '30008'),
+       ('audit_agent_instance_mgr_heartbeat', 'AGENT', 11, '30009'),
+       ('audit_agent_instance_heartbeat', 'AGENT', 12, '30010'),
+       ('audit_agent_sent_failed_realtime', 'AGENT', 13, '30011'),
+       ('audit_agent_del_instance_mem_unusual', 'AGENT', 14, '30014'),
        ('audit_dataproxy_received', 'DATAPROXY', 0, '5'),
        ('audit_dataproxy_sent', 'DATAPROXY', 1, '6'),
        ('audit_sort_hive_input', 'HIVE', 0, '7'),
        ('audit_sort_hive_output', 'HIVE', 1, '8'),
        ('audit_sort_clickhouse_input', 'CLICKHOUSE', 0, '9'),
        ('audit_sort_clickhouse_output', 'CLICKHOUSE', 1, '10'),
-       ('audit_sort_es_input', 'ELASTICSEARCH', 0, '11'),
-       ('audit_sort_es_output', 'ELASTICSEARCH', 1, '12'),
+       ('audit_sort_es_input', 'ES', 0, '11'),
+       ('audit_sort_es_output', 'ES', 1, '12'),
        ('audit_sort_starrocks_input', 'STARROCKS', 0, '13'),
        ('audit_sort_starrocks_output', 'STARROCKS', 1, '14'),
        ('audit_sort_hudi_input', 'HUDI', 0, '15'),
@@ -891,7 +907,13 @@ VALUES ('audit_sdk_collect', 'SDK', 0, '1'),
        ('audit_sort_kudu_input', 'KUDU', 0, '25'),
        ('audit_sort_kudu_output', 'KUDU', 1, '26'),
        ('audit_sort_postgres_input', 'POSTGRESQL', 0, '27'),
-       ('audit_sort_postgres_output', 'POSTGRESQL', 1, '28');
+       ('audit_sort_postgres_output', 'POSTGRESQL', 1, '28'),
+       ('audit_sort_mysql_binlog_input', 'MYSQL_BINLOG', 0, '29'),
+       ('audit_sort_mysql_binlog_output', 'MYSQL_BINLOG', 1, '30'),
+       ('audit_sort_pulsar_input', 'PULSAR', 0, '31'),
+       ('audit_sort_pulsar_output', 'PULSAR', 1, '32'),
+       ('audit_sort_tube_input', 'TUBEMQ', 0, '33'),
+       ('audit_sort_tube_output', 'TUBEMQ', 1, '34');
 
 -- ----------------------------
 -- Table structure for audit_source
@@ -917,6 +939,25 @@ CREATE TABLE IF NOT EXISTS `audit_source`
 ) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='Audit source table';
 
+-- ----------------------------
+-- Table structure for tenant_cluster_tag
+-- ----------------------------
+CREATE TABLE IF NOT EXISTS `tenant_cluster_tag`
+(
+    `id`          int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `tenant`      varchar(256) NOT NULL COMMENT 'Inlong tenant',
+    `cluster_tag` varchar(128) NOT NULL COMMENT 'Cluster tag',
+    `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
+    `creator`     varchar(64)  NOT NULL COMMENT 'Creator name',
+    `modifier`    varchar(64)           DEFAULT NULL COMMENT 'Modifier name',
+    `create_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`     int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_tenant_inlong_cluster_tag` (`tenant`, `cluster_tag`, `is_deleted`)
+) ENGINE = InnoDB
+  DEFAULT CHARSET = utf8mb4 COMMENT ='Tenant cluster tag table';
+
 -- ----------------------------
 
 SET FOREIGN_KEY_CHECKS = 1;
